@@ -2,7 +2,7 @@ package App::Yath::Command::test;
 use strict;
 use warnings;
 
-our $VERSION = '1.000000';
+our $VERSION = '0.999003';
 
 use App::Yath::Options;
 
@@ -18,6 +18,8 @@ use Test2::Harness::Util::JSON qw/encode_json decode_json JSON/;
 use Test2::Harness::Util qw/mod2file open_file/;
 use Test2::Util::Table qw/table/;
 
+use Test2::Harness::Util::Term qw/USE_ANSI_COLOR/;
+
 use File::Spec;
 
 use Time::HiRes qw/sleep time/;
@@ -75,7 +77,11 @@ look for the 't', and 't2' dirctories, as well as the 'test.pl' file.
 This command is always recursive when given directories.
 
 This command will add 'lib', 'blib/arch' and 'blib/lib' to the perl path for
-you by default.
+you by default (after any -I's). You can specify -l if you just want lib, -b if
+you just want the blib paths. If you specify both -l and -b both will be added
+in the order you specify (order relative to any -I options will also be
+preserved.  If you do not specify they will be added in this order: -I's, lib,
+blib/lib, blib/arch. You can also add --no-lib and --no-blib to avoid both.
 
 Any command line argument that is not an option will be treated as a test file
 or directory of test files to be run.
@@ -164,7 +170,7 @@ sub run {
     my $self = shift;
 
     my $settings = $self->settings;
-    my $plugins = $self->settings->yath->plugins;
+    my $plugins = $self->settings->harness->plugins;
 
     if ($self->start()) {
         $self->render();
@@ -216,12 +222,12 @@ sub start {
 
 sub setup_plugins {
     my $self = shift;
-    $_->setup($self->settings) for @{$self->settings->yath->plugins};
+    $_->setup($self->settings) for @{$self->settings->harness->plugins};
 }
 
 sub teardown_plugins {
     my $self = shift;
-    $_->teardown($self->settings) for @{$self->settings->yath->plugins};
+    $_->teardown($self->settings) for @{$self->settings->harness->plugins};
 }
 
 sub render {
@@ -231,7 +237,7 @@ sub render {
     my $settings  = $self->settings;
     my $renderers = $self->renderers;
     my $logger    = $self->logger;
-    my $plugins = $self->settings->yath->plugins;
+    my $plugins = $self->settings->harness->plugins;
 
     $plugins = [grep {$_->can('handle_event')} @$plugins];
 
@@ -372,7 +378,7 @@ sub populate_queue {
 
     my $state = $self->state;
     my $tasks_queue = $self->tasks_queue;
-    my $plugins = $self->settings->yath->plugins;
+    my $plugins = $self->settings->harness->plugins;
 
     $state->queue_run($run->queue_item($plugins));
 
@@ -402,7 +408,7 @@ sub produce_summary {
     my $settings = $self->settings;
 
     my $time_data = {
-        start => $settings->yath->start,
+        start => $settings->harness->start,
         stop  => time(),
     };
 
@@ -472,7 +478,7 @@ sub render_summary {
     );
 
     my $res = "    -->  Result: " . ($pass ? 'PASSED' : 'FAILED') . "  <--";
-    if ($self->settings->display->color && eval { require Term::ANSIColor; 1 }) {
+    if ($self->settings->display->color && USE_ANSI_COLOR) {
         my $color = $pass ? Term::ANSIColor::color('bold bright_green') : Term::ANSIColor::color('bold bright_red');
         my $reset = Term::ANSIColor::color('reset');
         $res = "$color$res$reset";
@@ -592,8 +598,8 @@ sub start_auditor {
         stdout      => $self->auditor_writer(),
         no_set_pgrp => 1,
         command     => [
-            $^X, cover(), $settings->yath->script,
-            (map { "-D$_" } @{$settings->yath->dev_libs}),
+            $^X, cover(), $settings->harness->script,
+            (map { "-D$_" } @{$settings->harness->dev_libs}),
             '--no-scan-plugins',    # Do not preload any plugin modules
             auditor => 'Test2::Harness::Auditor',
             $run->run_id,
@@ -620,8 +626,8 @@ sub start_collector {
         stdin       => $rh,
         no_set_pgrp => 1,
         command     => [
-            $^X, cover(), $settings->yath->script,
-            (map { "-D$_" } @{$settings->yath->dev_libs}),
+            $^X, cover(), $settings->harness->script,
+            (map { "-D$_" } @{$settings->harness->dev_libs}),
             '--no-scan-plugins',    # Do not preload any plugin modules
             collector => 'Test2::Harness::Collector',
             $dir, $run->run_id, $runner_pid,
@@ -651,8 +657,8 @@ sub start_runner {
         stdout => File::Spec->catfile($dir, 'output.log'),
         no_set_pgrp => 1,
         command => [
-            $^X, cover(), $settings->yath->script,
-            (map { "-D$_" } @{$settings->yath->dev_libs}),
+            $^X, cover(), $settings->harness->script,
+            (map { "-D$_" } @{$settings->harness->dev_libs}),
             '--no-scan-plugins', # Do not preload any plugin modules
             runner => $dir,
             %args,
